GoTrueAdminApi class

Constructors

GoTrueAdminApi(String _url, {Map<String, String>? headers, Client? httpClient})

Properties

hashCode int
The hash code for this object.
no setterinherited
mfa ↔ GoTrueAdminMFAApi
latefinal
oauth ↔ GoTrueAdminOAuthApi
Contains all OAuth client administration methods. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
latefinal
passkey GoTrueAdminPasskeyApi
Contains all passkey administration methods. Only relevant when passkeys are enabled in Supabase Auth.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createUser(AdminUserAttributes attributes) Future<UserResponse>
Creates a new user.
deleteUser(String id, {bool shouldSoftDelete = false}) Future<void>
Delete a user. Requires a secret key.
Generates links to be sent via email or other.
getUserById(String uid) Future<UserResponse>
Gets the user by their id.
inviteUserByEmail(String email, {String? redirectTo, Map<String, dynamic>? data}) Future<UserResponse>
Sends an invite link to an email address.
listUsers({int? page, int? perPage}) Future<List<User>>
Get a list of users.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signOut(String jwt, {SignOutScope scope = SignOutScope.global}) Future<void>
Removes a logged-in session.
toString() String
A string representation of this object.
inherited
updateUserById(String uid, {required AdminUserAttributes attributes}) Future<UserResponse>
Updates the user data.

Operators

operator ==(Object other) bool
The equality operator.
inherited