IcebergConflictException class final
The request conflicts with the current state, for example the resource already exists or a commit lost a race (HTTP 409).
- Inheritance
-
- Object
- IcebergException
- IcebergConflictException
Constructors
- IcebergConflictException(String message, {String? type, int? code, Object? details})
-
const
Properties
- code → int?
-
The Iceberg error code reported by the server.
finalinherited
- details → Object?
-
The raw error payload, when available.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human readable error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
The HTTP status code of the response.
0indicates a network level failure before a response was received.finalinherited - type → String?
-
The Iceberg error type reported by the server, for example
NoSuchTableException.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited