JwtPayload class

JWT Payload structure with standard claims

Constructors

JwtPayload({String? iss, String? sub, dynamic aud, int? exp, int? nbf, int? iat, String? jti, Map<String, dynamic>? claims})
JwtPayload.fromJson(Map<String, dynamic> json)
factory

Properties

aud → dynamic
Audience - identifies recipients that the JWT is intended for
final
claims Map<String, dynamic>
Additional claims stored in the payload
final
exp int?
Expiration time - timestamp after which the JWT must not be accepted
final
hashCode int
The hash code for this object.
no setterinherited
iat int?
Issued At - timestamp when the JWT was issued
final
iss String?
Issuer - identifies principal that issued the JWT
final
jti String?
JWT ID - unique identifier for the JWT
final
nbf int?
Not Before - timestamp before which the JWT must not be accepted
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sub String?
Subject - identifies the subject of the JWT
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited