JwtRawParts class

Raw encoded parts of a JWT

Constructors

JwtRawParts({required String header, required String payload, required String signature})

Properties

hashCode int
The hash code for this object.
no setterinherited
Raw base64url encoded header
final
payload String
Raw base64url encoded payload
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
Raw base64url encoded signature
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited