MapType class

A map type with keys of type key and values of type value.

Inheritance

Constructors

MapType({required int keyId, required IcebergType key, required int valueId, required IcebergType value, required bool valueRequired})
const
MapType.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key IcebergType
final
keyId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value IcebergType
final
valueId int
final
valueRequired bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited