PostgrestBuilder<T, S, R> class

The base builder class.

T for the overall return type, so PostgrestResponse<S> or S

When using _converter, S is the input and R is the output Otherwise S and R are the same

Implemented types
Available extensions
Annotations

Constructors

PostgrestBuilder({required Uri url, required Headers headers, String? schema, HttpMethod? method, Object? body, Client? httpClient, YAJsonIsolate? isolate, CountOption? count, bool maybeSingle = false, PostgrestConverter<S, R>? converter, bool retryEnabled = true, @visibleForTesting Duration retryDelay(int attempt)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSPromise<T>

Available on Future<T>, provided by the FutureOfJSAnyToJSPromise extension

A JSPromise that either resolves with the result of the completed Future or rejects with an object that contains its error.
no setter
toJS JSPromise<JSAny?>

Available on Future<void>, provided by the FutureOfVoidToJSPromise extension

A JSPromise that either resolves once this Future completes or rejects with an object that contains its error.
no setter

Methods

appendSearchParams(String key, String value, [Uri? url]) Uri
Get new Uri with updated queryParams Uses lists to allow multiple values for the same key
asStream() Stream<T>
Creates a Stream containing the result of this future.
override
catchError(Function onError, {bool test(Object error)?}) Future<T>
Handles errors emitted by this Future.
override
ignore() → void

Available on Future<T>, provided by the FutureExtensions extension

Completely ignores this future and its result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError<E extends Object>(FutureOr<T> handleError(E error, StackTrace stackTrace), {bool test(E error)?}) Future<T>

Available on Future<T>, provided by the FutureExtensions extension

Handles errors on this future.
overrideSearchParams(String key, String value, [Uri? url]) Uri
Get new Uri with overridden queryParams
retry({required bool enabled}) PostgrestBuilder<T, S, R>
Overrides the retry behavior for this specific request.
setHeader(String key, String value) PostgrestBuilder<T, S, R>
then<U>(FutureOr<U> onValue(T value), {Function? onError}) Future<U>
Register callbacks to be called when this future completes.
override
timeout(Duration timeLimit, {FutureOr<T> onTimeout()?}) Future<T>
Stop waiting for this future after timeLimit has passed.
override
toString() String
A string representation of this object.
inherited
whenComplete(FutureOr<void> action()) Future<T>
Registers a function to be called when this future completes.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited