RealtimeClientOptions class

Options to pass to the RealtimeClient.

Constructors

RealtimeClientOptions({int? eventsPerSecond, RealtimeLogLevel? logLevel, Duration? timeout, WebSocketTransport? transport})
Options to pass to the RealtimeClient.
const

Properties

eventsPerSecond int?
How many events the RealtimeClient can push in a second
final
hashCode int
The hash code for this object.
no setterinherited
logLevel RealtimeLogLevel?
Level of realtime server logs to be logged
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
the timeout to trigger push timeouts
final
transport WebSocketTransport?
Custom WebSocket transport factory for the RealtimeClient.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited