SortField class

A single field of a SortOrder.

Constructors

SortField({required int sourceId, required String transform, required SortDirection direction, required NullOrder nullOrder})
const
SortField.fromJson(Map<String, dynamic> json)
factory

Properties

direction SortDirection
final
hashCode int
The hash code for this object.
no setterinherited
nullOrder NullOrder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId int
final
transform String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited