useNewHostname property

bool useNewHostname
final

Whether to rewrite legacy storage URLs to use the dedicated storage host (<ref>.storage.supabase.co). Enables uploads larger than 50 GB by bypassing proxy buffering limits.

Set to true only if your project has the dedicated storage host enabled; otherwise every storage request will fail with an Invalid Storage request error. Defaults to false (opt-in).

Implementation

final bool useNewHostname;