StorageVectorBucketApi class

Index operations scoped to a single vector bucket.

Obtain an instance through SupabaseVectorsClient.from.

Annotations
  • @experimental

Properties

bucketName String
The name of the vector bucket these operations are scoped to.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createIndex({required String name, required int dimension, required DistanceMetric distanceMetric, VectorDataType dataType = VectorDataType.float32, List<String>? nonFilterableMetadataKeys}) Future<void>
Creates a new vector index in this bucket.
deleteIndex(String name) Future<void>
Deletes an index and all of its vectors from this bucket.
getIndex(String name) Future<VectorIndex>
Retrieves the metadata of an index in this bucket.
index(String indexName) StorageVectorIndexApi
Scopes vector data operations to the index named indexName in this bucket.
listIndexes({String? prefix, int? maxResults, String? nextToken}) Future<VectorIndexList>
Lists indexes in this bucket, optionally filtered by prefix and paginated with maxResults and nextToken.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited