TableMetadata class

Metadata describing the current state of a table, returned when loading or committing to a table.

Constructors

TableMetadata({required int formatVersion, required String tableUuid, required List<TableSchema> schemas, required int currentSchemaId, required List<PartitionSpec> partitionSpecs, required List<SortOrder> sortOrders, required Map<String, String> properties, String? location, int? lastUpdatedMs, int? lastColumnId, int? defaultSpecId, int? defaultSortOrderId, String? metadataLocation, int? currentSnapshotId, List<Snapshot> snapshots = const [], Map<String, SnapshotReference>? refs})
const
TableMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

currentSchema TableSchema?
The current (active) schema, or null when it can not be resolved.
no setter
currentSchemaId int
final
currentSnapshotId int?
final
defaultSortOrderId int?
final
defaultSpecId int?
final
formatVersion int
final
hashCode int
The hash code for this object.
no setterinherited
lastColumnId int?
final
lastUpdatedMs int?
final
location String?
final
metadataLocation String?
final
partitionSpecs List<PartitionSpec>
final
properties Map<String, String>
final
refs Map<String, SnapshotReference>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemas List<TableSchema>
final
snapshots List<Snapshot>
final
sortOrders List<SortOrder>
final
tableUuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited