GetClaimsOptions class
Options for getClaims method
Constructors
- GetClaimsOptions({bool allowExpired = false})
-
const
Properties
- allowExpired → bool
-
If set to
true, theexpclaim will not be validated against the current time. This allows you to extract claims from expired JWTs without getting an error.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited