PasskeyAuthenticationOptionsResponse class
Response containing the options needed to sign in with a passkey.
- Annotations
-
- @experimental
Constructors
-
PasskeyAuthenticationOptionsResponse({required String challengeId, required Map<
String, dynamic> options, required DateTime expiresAt}) -
const
-
PasskeyAuthenticationOptionsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- challengeId → String
-
ID of the challenge, pass it to GoTruePasskeyApi.verifyAuthentication
together with the signed assertion.
final
- expiresAt → DateTime
-
Timestamp when this challenge will no longer be usable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ Map<
String, dynamic> -
WebAuthn credential request options in the W3C
PublicKeyCredentialRequestOptionsJSONformat, with binary fields encoded as base64url strings.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited