StorageClientOptions class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
retryAttempts
→ int
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
useNewHostname
→ bool
-
Whether to rewrite legacy storage URLs to use the dedicated storage host
(
<ref>.storage.supabase.co). Enables uploads larger than 50 GB by
bypassing proxy buffering limits.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited