UpdateOAuthClientParams class
Parameters for updating an existing OAuth client. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
Constructors
-
UpdateOAuthClientParams({String? clientName, String? clientUri, List<
String> ? redirectUris, List<OAuthClientGrantType> ? grantTypes, List<OAuthClientResponseType> ? responseTypes, String? scope})
Properties
- clientName → String?
-
Human-readable name of the OAuth client
final
- clientUri → String?
-
URI of the OAuth client
final
-
grantTypes
→ List<
OAuthClientGrantType> ? -
Array of allowed grant types
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
redirectUris
→ List<
String> ? -
Array of allowed redirect URIs
final
-
responseTypes
→ List<
OAuthClientResponseType> ? -
Array of allowed response types
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String?
-
Scope of the OAuth client
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited